### Work handover
**Service description**
<table>
    <tr>
        <td>Method</td>
        <td>Work handover</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">This service is used for work handover (this method only marks the handover and does not actually modify permissions. The actual permission changes are executed after the work is received)</td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface</td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">public boolean handoverWork(List&lt;Map&lt;String,String&gt;&gt; list, boolean preservePermissions, String tenantid, String identifier)</td>
    </tr>
</table>

**Parameter Description**

| Parameter           | Type   | Required | Description                                     |
|---------------------|--------|----------|-------------------------------------------------|
| List &#60;Map&#62;  | List   |          |                                                 |
| Key=workid          | String | √        | List of tasks to be transferred (instance ID)   |
| Key=trackid         | String | √        | List of tasks to be transferred (path id)       |
| Key=olduserid       | String | √        | The transferor ID is prefixed, such as U_ Admin |
| Key=newuserid       | String | √        | Receiver ID with prefix, such as U_ Admin       |
| Key= newusername    | String | √        | Name of receiver                                |
| Key= oldusername    | String | √        | Name of transferor                              |
| preservePermissions | String | √        | keep permission 1, keep 0, and not keep it      |
| tenantid            | String | √        | Tenant ID                                       |
| identifier          | String | √        | Data source identification                      |
**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager();
boolean result = iwm.handoverWork(List<Map>,false,tenantid,identifier);
```
### Receive work handover
**Service description**
<table>
    <tr>
        <td>Method</td>
        <td>receiveHandoverWork</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">This interface is called after work handover to receive</td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">Map&lt;DBHandover,String&gt; receiveHandoverWork(List&lt;DBHandover&gt; list, String tenantid, String identifier)</td>
    </tr>
</table>

**Parameter Description**

| Parameter  | Type                      | Required | Description          |
|------------|---------------------------|----------|----------------------|
| List       | List &#60;DBHandover&#62; | √        | Work list to receive |
| tenantid   | String                    | √        | Tenant ID            |
| identifier | String                    | √        | Data source ID       |

**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager();
Map<DBHandover,String> result = iwm.receiveHandoverWork(list, tenantid, identifier);
```

### Activate process
**Service description**
<table>
    <tr>
        <td>Method</td>
        <td>activeTrack</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">This interface is used to activate the process</td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">boolean activeTrack(String workid,String trackid,String interfaceClass,String tenantid,String identifier)</td>
    </tr>
</table>

**Parameter Description**

| Parameter      | Type   | Required | Description                                                         |
|----------------|--------|----------|---------------------------------------------------------------------|
| workid         | String | √        | Instance ID                                                         |
| trackid        | String | √        | Path ID                                                             |
| interfaceClass | String | √        | The class to be executed during activation,containing the full path |
| tenantid       | String | √        | Tenant ID                                                           |
| identifier     | String | √        | Data source identification                                          |
**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManage();
boolean result = iwm.activeTrack(workid,trackid,interfaceclass,tenantid,identifier);
```

### Restore instance data
**Service description**
<table>
    <tr>
        <td>Method</td>
        <td>replaceWork</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">This interface is used to restore process instances to previous versions</td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">>boolean replaceWork(String workid,int version,String tenantid,String identifier)</td>
    </tr>
</table>

**Parameter Description**

| Parameter  | Type   | Required | Description    |
|------------|--------|----------|----------------|
| workid     | String | √        | Instance ID    |
| version    | int    | √        | Version        |
| tenantid   | String | √        | Tenant ID      |
| identifier | String | √        | Data source ID |
**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager();
boolean result = iwm.replaceWork(workid,trackid,tenantid,identifier);
```

### Obtain the maximum version number of the instance
**Service description**
<table>
    <tr>
        <td>Method</td>
        <td>getWorkMaxVersion</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">This interface is used to obtain the maximum version number of the specified process Instance ID</td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">int getWorkMaxVersion(String workid,String tenantid,String identifier)</td>
    </tr>
</table>

**Parameter Description**

| Parameter  | Type   | Required | Description    |
|------------|--------|----------|----------------|
| workid     | String | √        | Instance ID    |
| tenantid   | String | √        | Tenant ID      |
| identifier | String | √        | Data source ID |

**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager();
boolean result = iwm.getWorkMaxVersion(workid,trackid,identifier);
```

### Pause/Resume Instance
**Service description**
<table>
    <tr>
        <td>Method</td>
        <td>pauseWork</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">This interface is used to pause instances of specified workid and trackid</td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">boolean pauseWork(String workid,String trackid,String tenantid,String identifier)</td>
    </tr>
</table>

**Parameter Description**

| Parameter  | Type   | Required | Description    |
|------------|--------|----------|----------------|
| workid     | String | √        | Instance ID    |
| trackid    | String | √        | Track ID       |
| tenantid   | String | √        | Tenant ID      |
| identifier | String | √        | Data source ID |

**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager();
boolean result = iwm.pauseWork(workid,trackid,tenantid,identifier);
```

### Pause/resume instances by batch
**Service description**
<table>
    <tr>
        <td>Method</td>
        <td>pauseWork</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
         <td colspan="3">This interface is used to  pause instances of specified work id and track id (by batch)
</td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">String pauseWork(String[] workids,String[] trackids,String tenantid,String identifier
)<br>Returns the workid of the failed execution, multiple workid seperate with commas</td>
    </tr>
</table>

**Parameter Description**

| Parameter  | Type     | Required | Description    |
|------------|----------|----------|----------------|
| workids    | String[] | √        | Instance ID    |
| trackids   | String[] | √        | Track ID       |
| tenantid   | String   | √        | Tenant ID      |
| identifier | String   | √        | Data source ID |
**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager();
String[] workids ={"xxx"};
String[] trackids = {"yyy"};
String result = iwm. pauseWork (workids,trackids,tenantid,tenantid,identifier);
```

### End instance 
**Service description**
<table>
    <tr>
        <td>Method</td>
        <td>stopWork</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">This interface is used to change the current instance state to ended</td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">boolean stopWork(String workid,String trackid,String tenantid,String identifier)</td>
    </tr>
</table>

**Parameter Description**

| Parameter  | Type   | Required | Description    |
|------------|--------|----------|----------------|
| workid     | String | √        | Instance ID    |
| trackid    | String | √        | Track ID       |
| tenantid   | String | √        | Tenant ID      |
| identifier | String | √        | Data source ID |

**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager();
boolean result = iwm.stopWork(workid,trackid,tenantid,identifier);
```

### End instance by batch
**Service description**
<table>
    <tr>
        <td>Method</td>
        <td>stopWork</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">This interface is used to change the current instance status to ended by batch</td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">boolean stopWork(String workids,String trackids,String tenantid,String identifier)</td>
    </tr>
</table>

**Parameter Description**

| Parameter  | Type     | Required | Description    |
|------------|----------|----------|----------------|
| workids    | String[] | √        | Instance ID    |
| trackids   | String[] | √        | Track ID       |
| tenantid   | String   | √        | Tenant ID      |
| identifier | String   | √        | Data source ID |

**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager();
String[] workids ={"xxx"};
String[] trackids = {"yyy"};
String result = iwm.stopWork(workids,trackids,tenantid);
```

### Obtain node operator type  
**Service description**
<table>
    <tr>
        <td>Method</td>
        <td>getSelectType</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">When instance need to replace the node operator, the interface is used to obtain one or multiple options of operator</td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">int getSelectType(String workid,String trackid,String tenantid,String identifier)</td>
    </tr>
</table>

**Parameter Description**

| Parameter  | Type   | Required | Description    |
|------------|--------|----------|----------------|
| workid     | String | √        | Instance ID    |
| trackid    | String | √        | Track ID       |
| tenantid   | String | √        | Tenant ID      |
| identifier | String | √        | Data source ID |
**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager ();
int result = iwm.getSelectType(workid,trackid,tenantid,identifier);
```

###  Replace operator 
**Service description**
<table>
    <tr>
        <td>Method</td>
        <td>replaceAuthor</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">Substituted opertaors, separated by ';' between multiple users</td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">boolean replaceAuthor(String workid,String trackid,String userids,String tenantid,String identifier)</td>
    </tr>
</table>

**Parameter Description**

| Parameter  | Type   | Required | Description                                                    |
|------------|--------|----------|----------------------------------------------------------------|
| workid     | String | √        | Instance ID                                                    |
| trackid    | String | √        | Track ID                                                       |
| userids    | String | √        | Substituted opertaors, separated by ';' between multiple users |
| tenantid   | String | √        | Tenant ID                                                      |
| identifier | String | √        | Data source ID                                                 |
**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager();
boolean result = iwm.replaceAuthor(workid,trackid,userids,tenantid,identifier);
```
### Obtain node selection type  of operator 
**Service description**
<table>
    <tr>
        <td>Method</td>
        <td>getSelectType</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">When instance need to replace the node operator, the interface is used to obtain one or multiple options of operator</td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">int getSelectType(String workid,String trackid,String tenantid,String identifier)</td>
    </tr>
</table>

**Parameter Description**

| Parameter  | Type   | Required | Description    |
|------------|--------|----------|----------------|
| workid     | String | √        | Instance ID    |
| trackid    | String | √        | Track ID       |
| tenantid   | String | √        | Tenant ID      |
| identifier | String | √        | Data source ID |
**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager();
int result = iwm.getSelectType(workid,trackid,tenantid,identifier);
```

### Delete instances
**Service description**
<table>
    <tr>
        <td>Method</td>
         <td>deleteWork</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">This interface is used to delete instances</td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">boolean deleteWork(String workid,String tenantid,String identifier)</td>
    </tr>
</table>

**Parameter Description**

| Parameter  | Type   | Required | Description    |
|------------|--------|----------|----------------|
| workid     | String | √        | Instance ID    |
| tenantid   | String | √        | Tenant ID      |
| identifier | String | √        | Data source ID |
**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager();
boolean result =  iwm.deleteWork(workid,tenantid,identifier);
```

### Delete instances by batch
**Service description**
<table>
    <tr>
        <td>Method</td>
         <td>deleteWork</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">This interface is used to delete instances by batch</td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">boolean deleteWork(String[] workids,String tenantid,String identifier)</td>
    </tr>
</table>

**Parameter Description**

| Parameter  | Type     | Required | Description    |
|------------|----------|----------|----------------|
| workids    | String[] | √        | Instance ID    |
| tenantid   | String   | √        | Tenant ID      |
| identifier | String   | √        | Data source ID |
**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager();
String[] workids ={"xxx"};
boolean result = iwm.deleteWork(workids,tenantid,identifier);
```

### Update instance
**Service description**
<table>
    <tr>
        <td>Method</td>
        <td>updateWork</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">This interface is used to update instance data</td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">boolean updateWork(String workid,String tenantid,String identifier)</td>
    </tr>
</table>

**Parameter Description**

| Parameter  | Type   | Required | Description    |
|------------|--------|----------|----------------|
| workid     | String | √        | Instance ID    |
| tenantid   | String | √        | Tenant ID      |
| identifier | String | √        | Data source ID |
**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager();
boolean result =  iwm.updateWork(workid,tenantid,identifier);
```

### Update instances by batch
**Service description**
<table>
    <tr>
        <td>Method</td>
        <td>updateWork</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">This interface is used to update instance data by batch </td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">Map&lt;String,Boolean&gt; updateWork(String[] workids,String tenantid,String identifier)</td>
    </tr>
</table>

**Parameter Description**

| Parameter  | Type     | Required | Description    |
|------------|----------|----------|----------------|
| workids    | String[] | √        | Instance ID    |
| tenantid   | String   | √        | Tenant ID      |
| identifier | String   | √        | Data source ID |
**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager();
String[] workids ={"xxx"};
Map<String, Boolean> result = iwm.updateWork(workids,tenantid,identifier);
```
### Query user to-do list
**Service description**
<table>
    <tr>
        <td>Method</td>
        <td>getTodoList</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">This interface is used to query the to-do list of specified users</td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">List&lt;DBTodo&gt; getTodoList(TodoPara todoPara)</td>
    </tr>
</table>

**Parameter Description**

| Parameter       | Type         | Required            | Description                                                                                                                                                                                 |
|-----------------|--------------|---------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| setAlluserid()  | String       | √                   | User ID                                                                                                                                                                                     |
| setFlowid()     | String       |                     | Process ID (this parameter can be passed when querying process instances initiated by users)                                                                                                |
| setIdentifier() | String       | √                   | Data source ID                                                                                                                                                                              |
| setPageNum()    | int          | Required for paging | Current number of pages                                                                                                                                                                     |
| setPageSize()   | int          | Required for paging | Display rows per page                                                                                                                                                                       |
| setTenantid()   | String       | √                   | Tenant ID                                                                                                                                                                                   |
| setUserid()     | String       | √                   | Current  User ID                                                                                                                                                                            |
| setWhere()      | String       |                     | Additional query condition<br>such as and title=? or flowname=?                                                                                                                             |
| setPara()       | List<String> |                     | Parameter values corresponding to additional query conditions<br>Maintain consistency with the number and order of question marks, such as :List.add(titlevalue)<br>List.add(flownamevalue) |
| setOrderby()    | String       |                     | Data sorting field 如：order by title                                                                                                                                                         |
**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager();	
TodoPara para = new TodoPara();
para.setIdentifier("system");
para.setTenantid("system");
......
List<DBTodo> result = iwm.getTodoList(para);
```
### Query user to-do quantity
**Service description**
<table>
    <tr>
        <td>Method</td>
        <td>getTodoCount</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">This interface is used to query the to-do quantity of a specified user</td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">int getTodoCount(TodoPara todoPara)</td>
    </tr>
</table>

**Parameter Description**

| Parameter       | Type         | Required | Description                                                                                                                                                                                 |
|-----------------|--------------|----------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| setAlluserid()  | String       | √        | User ID                                                                                                                                                                                     |
| setIdentifier() | String       | √        | Data source ID                                                                                                                                                                              |
| setTenantid()   | String       | √        | Tenant ID                                                                                                                                                                                   |
| setUserid()     | String       | √        | Current  User ID                                                                                                                                                                            |
| setWhere()      | String       |          | Additional query condition<br>such as and title=? or flowname=?                                                                                                                             |
| setPara()       | List<String> |          | Parameter values corresponding to additional query conditions<br>Maintain consistency with the number and order of question marks, such as :List.add(titlevalue)<br>List.add(flownamevalue) |
| setOrderby()    | String       |          | Data sorting field 如：order by title                                                                                                                                                         |
**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager();
TodoPara para = new TodoPara();
para.setIdentifier("system");
para.setTenantid("system");
......
int result =  iwm.getTodoCount(para);
```
### Query specified user's processed list  
**Service description**
<table>
    <tr>
        <td>Method</td>
        <td>getHasTodoList</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">This interface is used to query specified user‘s  processed list </td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">List&lt;DBTodo&gt; getHasTodoList(TodoPara para)</td>
    </tr>
</table>

**Parameter Description**

| Parameter       | Type         | Required            | Description                                                                                                                                                                |
|-----------------|--------------|---------------------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| setAlluserid()  | String       | √                   | User ID                                                                                                                                                                    |
| setFlowid()     | String       |                     | Process ID (this parameter can be passed when querying process instances initiated by users)                                                                               |
| setIdentifier() | String       | √                   | Data source ID                                                                                                                                                             |
| setPageNum()    | int          | Required for paging | Current number of pages                                                                                                                                                    |
| setPageSize()   | int          | Required for paging | Display rows per page                                                                                                                                                      |
| setTenantid()   | String       | √                   | Tenant ID                                                                                                                                                                  |
| setUserid()     | String       | √                   | Current  User ID                                                                                                                                                           |
| setWhere()      | String       |                     | Additional query condition<br>such as and title=? or flowname=?                                                                                                            |
| setPara()       | List<String> |                     | Parameter values corresponding to additional query conditions<br>Consistent with the number and order of question marks 如 :List.add(titlevalue)<br>List.add(flownamevalue) |
| setOrderby()    | String       |                     | Data sorting fields ,such as：order by title                                                                                                                                |                                                |
**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager();
TodoPara para = new TodoPara();
para.setIdentifier("system");
para.setTenantid("system");
......
List<DBTodo> result =  iwm.getHasTodoList(para);
```
### Query quantity of user's processed task
**Service description**
<table>
    <tr>
        <td>Method</td>
        <td>getHasTodoCount</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">This interface is used to query the quantity of specified user's processed task</td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">int getHasTodoCount(TodoPara para)</td>
    </tr>
</table>

**Parameter Description**

| Parameter       | Type         | Required | Description                                                                                                                                                                |
|-----------------|--------------|----------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| setAlluserid()  | String       | √        | User ID                                                                                                                                                                    |
| setIdentifier() | String       | √        | Data source ID                                                                                                                                                             |
| setTenantid()   | String       | √        | Tenant ID                                                                                                                                                                  |
| setUserid()     | String       | √        | Current  User ID                                                                                                                                                           |
| setWhere()      | String       |          | Additional query condition<br>such as and title=? or flowname=?                                                                                                            |
| setPara()       | List<String> |          | Parameter values corresponding to additional query conditions<br>Consistent with the number and order of question marks 如 :List.add(titlevalue)<br>List.add(flownamevalue) |
| setOrderby()    | String       |          | Data sorting fields, such as：order by title                                                                                                                                |
**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager();
TodoPara para = new TodoPara();
para.setIdentifier("system");
para.setTenantid("system");
......
int result = iwm.getHasTodoCount(para);
```
### Query specified user's to be read list  
**Service description**
<table>
    <tr>
        <td>Method</td>
        <td>getToBeReadList</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">This interface is used to query specified user's to be read list  </td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">List&lt;DBTodo&gt; getToBeReadList(TodoPara para)</td>
    </tr>
</table>

**Parameter Description**

| Parameter       | Type         | Required            | Description                                                                                                                                                                |
|-----------------|--------------|---------------------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| setAlluserid()  | String       | √                   | User ID                                                                                                                                                                    |
| setFlowid()     | String       |                     | Process ID (this parameter can be passed when querying process instances initiated by users)                                                                               |
| setIdentifier() | String       | √                   | Data source ID                                                                                                                                                             |
| setPageNum()    | int          | Required for paging | Current number of pages                                                                                                                                                    |
| setPageSize()   | int          | Required for paging | Display rows per page                                                                                                                                                      |
| setTenantid()   | String       | √                   | Tenant ID                                                                                                                                                                  |
| setUserid()     | String       | √                   | Current  User ID                                                                                                                                                           |
| setWhere()      | String       |                     | Additional query condition<br>such as and title=? or flowname=?                                                                                                            |
| setPara()       | List<String> |                     | Parameter values corresponding to additional query conditions<br>Consistent with the number and order of question marks 如 :List.add(titlevalue)<br>List.add(flownamevalue) |
| setOrderby()    | String       |                     | Data sorting fields, such as：order by title                                                                                                                                |                                                |
**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager ();
TodoPara para = new TodoPara();
para.setIdentifier("system");
para.setTenantid("system");
......
List<DBTodo> result =  iwm.getToBeReadList(para);
```
### Query specified user's quantity of to be read list   
**Service description**
<table>
    <tr>
        <td>Method</td>
        <td>getToBeReadCount</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">This interface is used to query specified user's quantity of to be read list </td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">int getToBeReadCount(TodoPara para)</td>
    </tr>
</table>

**Parameter Description**

| Parameter       | Type         | Required | Description                                                                                                                                                                |
|-----------------|--------------|----------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| setAlluserid()  | String       | √        | User ID                                                                                                                                                                    |
| setIdentifier() | String       | √        | Data source ID                                                                                                                                                             |
| setTenantid()   | String       | √        | Tenant ID                                                                                                                                                                  |
| setUserid()     | String       | √        | Current  User ID                                                                                                                                                           |
| setWhere()      | String       |          | Additional query condition<br>如 and title=? or flowname=?                                                                                                                  |
| setPara()       | List<String> |          | Parameter values corresponding to additional query conditions<br>Consistent with the number and order of question marks 如 :List.add(titlevalue)<br>List.add(flownamevalue) |
| setOrderby()    | String       |          | Data sorting fields, such as：order by title                                                                                                                                |
**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager();
TodoPara para = new TodoPara();
para.setIdentifier("system");
para.setTenantid("system");
......
int result = iwm.getToBeReadCount(para);
```
### Query specified user's reviewed list   
**Service description**
<table>
    <tr>
        <td>Method</td>
         <td>getHaveReadList</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">This interface is to query specified user's reviewed list </td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">List&lt;DBTodo&gt; getHaveReadList(TodoPara para)</td>
    </tr>
</table>

**Parameter Description**

| Parameter       | Type         | Required            | Description                                                                                                                                                                |
|-----------------|--------------|---------------------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| setAlluserid()  | String       | √                   | User ID                                                                                                                                                                    |
| setFlowid()     | String       |                     | Process ID (this parameter can be passed when querying process instances initiated by users)                                                                               |
| setIdentifier() | String       | √                   | Data source ID                                                                                                                                                             |
| setPageNum()    | int          | Required for paging | Current number of pages                                                                                                                                                    |
| setPageSize()   | int          | Required for paging | Display rows per page                                                                                                                                                      |
| setTenantid()   | String       | √                   | Tenant ID                                                                                                                                                                  |
| setUserid()     | String       | √                   | Current  User ID                                                                                                                                                           |
| setWhere()      | String       |                     | Additional query condition<br>如 and title=? or flowname=?                                                                                                                  |
| setPara()       | List<String> |                     | Parameter values corresponding to additional query conditions<br>Consistent with the number and order of question marks 如 :List.add(titlevalue)<br>List.add(flownamevalue) |
| setOrderby()    | String       |                     | Data sorting fields, such as：order by title                                                                                                                                |                                                |
**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager ();
TodoPara para = new TodoPara();
para.setIdentifier("system");
para.setTenantid("system");
......
List<DBTodo> result = iwm.getHaveReadList(para);
```
### Query specified user's quantity of  reviewed  
**Service description**
<table>
    <tr>
        <td>Method</td>
       <td>getHaveReadCount</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">This interface is used to query specified user's quantity of  reviewed  </td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">int getHaveReadCount(TodoPara para)</td>
    </tr>
</table>

**Parameter Description**

| Parameter       | Type         | Required | Description                                                                                                                                                                       |
|-----------------|--------------|----------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| setAlluserid()  | String       | √        | User ID                                                                                                                                                                           |
| setIdentifier() | String       | √        | Data source ID                                                                                                                                                                    |
| setTenantid()   | String       | √        | Tenant ID                                                                                                                                                                         |
| setUserid()     | String       | √        | Current  User ID                                                                                                                                                                  |
| setWhere()      | String       |          | Additional query condition<br>such as, and title=? or flowname=?                                                                                                                  |
| setPara()       | List<String> |          | Parameter values corresponding to additional query conditions<br>Consistent with the number and order of question marks ,such as :List.add(titlevalue)<br>List.add(flownamevalue) |
| setOrderby()    | String       |          | Data sorting fields, such as：order by title                                                                                                                                       |
**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager();
TodoPara para = new TodoPara();
para.setIdentifier("system");
para.setTenantid("system");
......
int result = iwm.getHaveReadCount(para);
```
### Query the list of specified user's to-do tasks that need to be claimed.
**Service description**
<table>
    <tr>
        <td>Method</td>
        <td>getClaimList</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">This interface is used to query the list of specified user's to-do tasks that need to be claimed.</td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">List&lt;DBTodo&gt; getClaimList(TodoPara para)</td>
    </tr>
</table>

**Parameter Description**

| Parameter       | Type         | Required            | Description                                                                                                                                                                       |
|-----------------|--------------|---------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| setAlluserid()  | String       | √                   | User ID                                                                                                                                                                           |
| setFlowid()     | String       |                     | Process ID (this parameter can be passed when querying process instances initiated by users)                                                                                      |
| setIdentifier() | String       | √                   | Data source ID                                                                                                                                                                    |
| setPageNum()    | int          | Required for paging | Current number of pages                                                                                                                                                           |
| setPageSize()   | int          | Required for paging | Display rows per page                                                                                                                                                             |
| setTenantid()   | String       | √                   | Tenant ID                                                                                                                                                                         |
| setUserid()     | String       | √                   | Current  User ID                                                                                                                                                                  |
| setWhere()      | String       |                     | Additional query condition<br>such as, and title=? or flowname=?                                                                                                                  |
| setPara()       | List<String> |                     | Parameter values corresponding to additional query conditions<br>Consistent with the number and order of question marks ,such as :List.add(titlevalue)<br>List.add(flownamevalue) |
| setOrderby()    | String       |                     | Data sorting fields, such as：order by title                                                                                                                                       |                                                |
**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager ();
TodoPara para = new TodoPara();
para.setIdentifier("system");
para.setTenantid("system");
......
List<DBTodo> result = iwm.getClaimList(para);
```
### Query the quantity of specified user's to-do tasks that need to be claimed.
**Service description**
<table>
    <tr>
        <td>Method</td>
        <td>getClaimCount</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">This interface is used to query the quantity of specified user's to-do tasks that need to be claimed</td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">int getClaimCount(TodoPara para)</td>
    </tr>
</table>

**Parameter Description**

| Parameter       | Type         | Required | Description                                                                                                                                                                       |
|-----------------|--------------|----------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| setAlluserid()  | String       | √        | User ID                                                                                                                                                                           |
| setIdentifier() | String       | √        | Data source ID                                                                                                                                                                    |
| setTenantid()   | String       | √        | Tenant ID                                                                                                                                                                         |
| setUserid()     | String       | √        | Current  User ID                                                                                                                                                                  |
| setWhere()      | String       |          | Additional query condition<br>such as, and title=? or flowname=?                                                                                                                  |
| setPara()       | List<String> |          | Parameter values corresponding to additional query conditions<br>Consistent with the number and order of question marks ,such as :List.add(titlevalue)<br>List.add(flownamevalue) |
| setOrderby()    | String       |          | Data sorting fields, such as：order by title                                                                                                                                       |
**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager();
TodoPara para = new TodoPara();
para.setIdentifier("system");
para.setTenantid("system");
......
int result = iwm.getClaimCount(para);
```
### Query the list of specified user's readable instances 
**Service description**
<table>
    <tr>
        <td>Method</td>
        <td>getCReaderList</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">This  interface is used to query the list of specified user's readable instances </td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">List&lt;DBTodo&gt; getCReaderList(TodoPara para)</td>
    </tr>
</table>

**Parameter Description**

| Parameter       | Type         | Required            | Description                                                                                                                                                                        |
|-----------------|--------------|---------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| setAlluserid()  | String       | √                   | User ID                                                                                                                                                                            |
| setFlowid()     | String       |                     | Process ID (this parameter can be passed when querying process instances initiated by users)                                                                                       |
| setIdentifier() | String       | √                   | Data source ID                                                                                                                                                                     |
| setPageNum()    | int          | Required for paging | Current number of pages                                                                                                                                                            |
| setPageSize()   | int          | Required for paging | Display rows per page                                                                                                                                                              |
| setTenantid()   | String       | √                   | Tenant ID                                                                                                                                                                          |
| setUserid()     | String       | √                   | Current  User ID                                                                                                                                                                   |
| setWhere()      | String       |                     | Additional query condition<br>such as, and title=? or flowname=?                                                                                                                   |
| setPara()       | List<String> |                     | Parameter values corresponding to additional query conditions<br>Consistent with the number and order of question marks ,such as  :List.add(titlevalue)<br>List.add(flownamevalue) |
| setOrderby()    | String       |                     | Data sorting fields, such as：order by title                                                                                                                                        |                                                |
**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager ();
TodoPara para = new TodoPara();
para.setIdentifier("system");
para.setTenantid("system");
......
List<DBTodo> result = iwm.getCReaderList(para);
```
### Query the quantity of specified user's readable instances 
**Service description**
<table>
    <tr>
        <td>Method</td>
        <td>getCReaderCount</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">This interface is used to query the quantity of specified user's readable instances </td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">int getCReaderCount(TodoPara para)</td>
    </tr>
</table>

**Parameter Description**

| Parameter       | Type         | Required | Description                                                                                                                                                                        |
|-----------------|--------------|----------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| setAlluserid()  | String       | √        | User ID                                                                                                                                                                            |
| setIdentifier() | String       | √        | Data source ID                                                                                                                                                                     |
| setTenantid()   | String       | √        | Tenant ID                                                                                                                                                                          |
| setUserid()     | String       | √        | Current  User ID                                                                                                                                                                   |
| setWhere()      | String       |          | Additional query condition<br>such as , and title=? or flowname=?                                                                                                                  |
| setPara()       | List<String> |          | Parameter values corresponding to additional query conditions<br>Consistent with the number and order of question marks ,such as  :List.add(titlevalue)<br>List.add(flownamevalue) |
| setOrderby()    | String       |          | Data sorting fields, such as：order by title                                                                                                                                        |
**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager();
TodoPara para = new TodoPara();
para.setIdentifier("system");
para.setTenantid("system");
......
int result = iwm.getCReaderCount(para);
```
### Query  the list of  process instances that specified user has  launched
**Service description**
<table>
    <tr>
        <td>Method</td>
        <td>getMyStartList</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">This interface is used to query  the list of  process instances that specified user has  launched</td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">List&lt;DBTodo&gt; getMyStartList(TodoPara para)</td>
    </tr>
</table>

**Parameter Description**

| Parameter       | Type         | Required            | Description                                                                                                                                                                              |
|-----------------|--------------|---------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| setAlluserid()  | String       | √                   | User ID                                                                                                                                                                                  |
| setFlowid()     | String       |                     | Process ID (this parameter can be passed when querying process instances initiated by users)                                                                                             |
| setIdentifier() | String       | √                   | Data source ID                                                                                                                                                                           |
| setPageNum()    | int          | Required for paging | Current number of pages                                                                                                                                                                  |
| setPageSize()   | int          | Required for paging | Display rows per page                                                                                                                                                                    |
| setTenantid()   | String       | √                   | Tenant ID                                                                                                                                                                                |
| setUserid()     | String       | √                   | Current  User ID                                                                                                                                                                         |
| setWhere()      | String       |                     | Additional query condition<br>such as, and title=? or flowname=?                                                                                                                         |
| setPara()       | List<String> |                     | The parameter values corresponding to the additional query condition<br>Consistent with the number and order of question marks ,such as :List.add(titlevalue)<br>List.add(flownamevalue) |
| setOrderby()    | String       |                     | Data sorting fields, such as：order by title                                                                                                                                              |                                                |
**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager ();
TodoPara para = new TodoPara();
para.setIdentifier("system");
para.setTenantid("system");
......
List<DBTodo> result = iwm.getMyStartList(para);
```
### Query the quantity of process instances that specified user has  launched
**Service description**
<table>
    <tr>
        <td>Method</td>
        <td>getMyStartCount</td>
        <td>  </td>
        <td>  </td>
    </tr>
    <tr>
        <td>Function description</td>
        <td colspan="3">This interface is used to query the quantity of process instances that specified user has  launched</td>
    </tr>
    <tr>
        <td colspan="4" align="center">Interface </td>
    </tr>
    <tr>
        <td>Interface type</td>
        <td>api</td>
        <td>Interaction frequency</td>
        <td>Aperiodic</td>
    </tr>
    <tr>
        <td>Interface protocol</td>
        <td>Direct method invocation</td>
        <td>Response time</td>
        <td></td>
    </tr>
   <tr>
        <td>Comments</td>
        <td colspan="3">int getMyStartCount(TodoPara para)</td>
    </tr>
</table>

**Parameter Description**

| Parameter       | Type         | Required | Description                                                                                                                                                                              |
|-----------------|--------------|----------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| setAlluserid()  | String       | √        | User ID                                                                                                                                                                                  |
| setIdentifier() | String       | √        | Data source ID                                                                                                                                                                           |
| setTenantid()   | String       | √        | Tenant ID                                                                                                                                                                                |
| setUserid()     | String       | √        | Current  User ID                                                                                                                                                                         |
| setWhere()      | String       |          | Additional query condition<br>such as, and title=? or flowname=?                                                                                                                         |
| setPara()       | List<String> |          | The parameter values corresponding to the additional query condition<br>Consistent with the number and order of question marks ,such as :List.add(titlevalue)<br>List.add(flownamevalue) |
| setOrderby()    | String       |          | Data sorting fields, such as：order by title                                                                                                                                              |
**Invocation example**
```
//Interface for process management related methods
IWorkflowManager iwm = WorkflowFactory.getWorkflowManager();
TodoPara para = new TodoPara();
para.setIdentifier("system");
para.setTenantid("system");
......
int result = iwm.getMyStartCount(para);
```


